'# MWS Version: Version 2011.7 - Dec  1 2011 - 05:23:21 - ACIS 21.0.0 -

'# length = mm
'# frequency = GHz
'# time = ns
'# frequency range: fmin = 0.0 fmax = 10.0


'@ use template: Filter (Planar, Microstrip, cpw)

'[VERSION]2011.7|21.0.0|20111130[/VERSION]
' Template for Planar Filter
' ==========================
' (CSTxMWSxONLY)
' draw the bounding box
Plot.DrawBox True
' set units to mm, ghz
With Units 
     .Geometry "mm" 
     .Frequency "ghz" 
     .Time "ns" 
End With 
' set background material to vacuum
With Background 
     .Type "Normal" 
     .Epsilon "1.0" 
     .Mue "1.0" 
     .XminSpace "0.0" 
     .XmaxSpace "0.0" 
     .YminSpace "0.0" 
     .YmaxSpace "0.0" 
     .ZminSpace "0.0" 
     .ZmaxSpace "0.0" 
End With 
' set boundary conditions to electric
With Boundary
     .Xmin "electric" 
     .Xmax "electric" 
     .Ymin "electric" 
     .Ymax "electric" 
     .Zmin "electric" 
     .Zmax "electric" 
     .Xsymmetry "none" 
     .Ysymmetry "none" 
     .Zsymmetry "none" 
End With
' optimize mesh settings for planar structures
With Mesh 
     .MergeThinPECLayerFixpoints "True"
     .RatioLimit "20" 
     .AutomeshRefineAtPecLines "True", "6"
     .FPBAAvoidNonRegUnite "True" 
     .ConsiderSpaceForLowerMeshLimit "False"
     .AnisotropicCurvatureRefinement "True"
     .AnisotropicCurvatureRefinementFSM "True"
End With 
MeshSettings.SetMeshType "HexTLM" 
With MeshSettings 
     .Set "RatioLimitGeometry", "20" 
End With 
' increase maximum number of pulses to simulation (resonant structure)
' use Online AR Filter
With Solver 
     .NumberOfPulseWidths "50" 
     .UseArfilter "True"
End With 
' change mesh adaption scheme to energy 
' 		(planar structures tend to store high energy 
'     	 locally at edges rather than globally in volume)
MeshAdaption3D.SetAdaptionStrategy "Energy"

'@ set workplane properties

'[VERSION]2011.7|21.0.0|20111130[/VERSION]
With WCS
     .SetWorkplaneSize "10"
     .SetWorkplaneRaster "1"
     .SetWorkplaneAutoadjust "False"
     .SetWorkplaneSnap "False"
     .SetWorkplaneSnapRaster "0.1"
     .SetWorkplaneSnapAutoadjust "False"
End With

'@ activate local coordinates

'[VERSION]2011.7|21.0.0|20111130[/VERSION]
WCS.ActivateWCS "local"

'@ define material: Taconic RF-35 (lossy)

'[VERSION]2011.7|21.0.0|20111130[/VERSION]
With Material
     .Reset
     .Name "Taconic RF-35 (lossy)"
.FrqType "all" 
.Type "Normal" 
.SetMaterialUnit "GHz", "mm"
.Epsilon "3.5" 
.Mue "1.0" 
.Kappa "0.0" 
.TanD "0.0018" 
.TanDFreq "1.9" 
.TanDGiven "True" 
.TanDModel "ConstTanD" 
.KappaM "0.0" 
.TanDM "0.0" 
.TanDMFreq "0.0" 
.TanDMGiven "False" 
.TanDMModel "ConstKappa" 
.DispModelEps "None" 
.DispModelMue "None" 
.DispersiveFittingSchemeEps "General 1st" 
.DispersiveFittingSchemeMue "General 1st" 
.UseGeneralDispersionEps "False" 
.UseGeneralDispersionMue "False" 
.Rho "0.0" 
.ThermalType "Normal" 
.ThermalConductivity "0.24" 
.SetActiveMaterial "all" 
.Colour "0.94", "0.82", "0.76" 
.Wireframe "False" 
.Transparency "0" 
.Create
End With

'@ new component: component1

'[VERSION]2011.7|21.0.0|20111130[/VERSION]
Component.New "component1"

'@ define brick: component1:substrate

'[VERSION]2011.7|21.0.0|20111130[/VERSION]
With Brick
     .Reset 
     .Name "substrate" 
     .Component "component1" 
     .Material "Taconic RF-35 (lossy)" 
     .Xrange "-1.5", "1.5" 
     .Yrange "0", "5" 
     .Zrange "0", "0.76" 
     .Create
End With

'@ pick face

'[VERSION]2011.7|21.0.0|20111130[/VERSION]
Pick.PickFaceFromId "component1:substrate", "2"

'@ define material: Copper (hard-drawn)

'[VERSION]2011.7|21.0.0|20111130[/VERSION]
With Material
     .Reset
     .Name "Copper (hard-drawn)"
.FrqType "all" 
.Type "Lossy metal" 
.SetMaterialUnit "GHz", "mm" 
.Mue "1.0" 
.Kappa "5.96e+007" 
.Rho "8930.0" 
.ThermalType "Normal" 
.ThermalConductivity "401.0" 
.HeatCapacity "0.39" 
.MetabolicRate "0" 
.BloodFlow "0" 
.VoxelConvection "0" 
.MechanicsType "Isotropic" 
.YoungsModulus "120" 
.PoissonsRatio "0.33" 
.ThermalExpansionRate "17" 
.FrqType "static" 
.Type "Normal" 
.SetMaterialUnit "Hz", "mm" 
.Epsilon "1" 
.Mue "1.0" 
.Kappa "5.96e+007" 
.TanD "0.0" 
.TanDFreq "0.0" 
.TanDGiven "False" 
.TanDModel "ConstTanD" 
.KappaM "0" 
.TanDM "0.0" 
.TanDMFreq "0.0" 
.TanDMGiven "False" 
.TanDMModel "ConstTanD" 
.DispModelEps "None" 
.DispModelMue "None" 
.DispersiveFittingSchemeEps "1st Order" 
.DispersiveFittingSchemeMue "1st Order" 
.UseGeneralDispersionEps "False" 
.UseGeneralDispersionMue "False" 
.Colour "1", "1", "0" 
.Wireframe "False" 
.Reflection "False" 
.Allowoutline "True" 
.Transparentoutline "False" 
.Transparency "0" 
.Create
End With

'@ define extrude: component1:ground plane

'[VERSION]2011.7|21.0.0|20111130[/VERSION]
With Extrude 
     .Reset 
     .Name "ground plane" 
     .Component "component1" 
     .Material "Copper (hard-drawn)" 
     .Mode "Picks" 
     .Height "0.0" 
     .Twist "0.0" 
     .Taper "0.0" 
     .UsePicksForHeight "False" 
     .DeleteBaseFaceSolid "False" 
     .ClearPickedFace "True" 
     .Create 
End With

'@ define extrude: component1:meander line

'[VERSION]2011.7|21.0.0|20111130[/VERSION]
With Extrude 
     .Reset 
     .Name "meander line" 
     .Component "component1" 
     .Material "Copper (hard-drawn)" 
     .Mode "Pointlist" 
     .Height "0.005" 
     .Twist "0.0" 
     .Taper "0.0" 
     .Origin "0.0", "0.0", "0.76" 
     .Uvector "1.0", "0.0", "0.0" 
     .Vvector "0.0", "1.0", "0.0" 
     .Point "0", "0.6" 
     .LineTo "0", "0.9" 
     .LineTo "-0.6", "0.9" 
     .LineTo "-0.6", "4.2" 
     .LineTo "-1.5", "4.2" 
     .LineTo "-1.5", "3.9" 
     .LineTo "-0.9", "3.9" 
     .LineTo "-0.9", "0.6" 
     .Create 
End With

'@ set workplane properties

'[VERSION]2011.7|21.0.0|20111130[/VERSION]
With WCS
     .SetWorkplaneSize "18.2"
     .SetWorkplaneRaster "0.2"
     .SetWorkplaneAutoadjust "False"
     .SetWorkplaneSnap "False"
     .SetWorkplaneSnapRaster "0.1"
     .SetWorkplaneSnapAutoadjust "False"
End With

'@ transform: mirror component1:meander line

'[VERSION]2011.7|21.0.0|20111130[/VERSION]
With Transform 
     .Reset 
     .Name "component1:meander line" 
     .Origin "Free" 
     .Center "0", "0", "0" 
     .PlaneNormal "1", "0", "0" 
     .MultipleObjects "True" 
     .GroupObjects "False" 
     .Repetitions "1" 
     .MultipleSelection "False" 
     .Destination "" 
     .Material "" 
     .Transform "Shape", "Mirror" 
End With

'@ boolean add shapes: component1:meander line, component1:meander line_1

'[VERSION]2011.7|21.0.0|20111130[/VERSION]
Solid.Add "component1:meander line", "component1:meander line_1"

'@ pick face

'[VERSION]2011.7|21.0.0|20111130[/VERSION]
Pick.PickFaceFromId "component1:substrate", "4"

'@ align wcs with face

'[VERSION]2011.7|21.0.0|20111130[/VERSION]
WCS.AlignWCSWithSelected "Face"

'@ pick face

'[VERSION]2011.7|21.0.0|20111130[/VERSION]
Pick.PickFaceFromId "component1:substrate", "3"

'@ align wcs with face

'[VERSION]2011.7|21.0.0|20111130[/VERSION]
WCS.AlignWCSWithSelected "Face"

'@ set workplane properties

'[VERSION]2011.7|21.0.0|20111130[/VERSION]
With WCS
     .SetWorkplaneSize "10"
     .SetWorkplaneRaster "0.2"
     .SetWorkplaneAutoadjust "False"
     .SetWorkplaneSnap "False"
     .SetWorkplaneSnapRaster "0.1"
     .SetWorkplaneSnapAutoadjust "False"
End With

'@ define boundaries

'[VERSION]2011.7|21.0.0|20111130[/VERSION]
With Boundary
     .Xmin "periodic" 
     .Xmax "periodic" 
     .Ymin "electric" 
     .Ymax "electric" 
     .Zmin "electric" 
     .Zmax "electric" 
     .Xsymmetry "none" 
     .Ysymmetry "none" 
     .Zsymmetry "none" 
     .XminThermal "isothermal" 
     .XmaxThermal "isothermal" 
     .YminThermal "isothermal" 
     .YmaxThermal "isothermal" 
     .ZminThermal "isothermal" 
     .ZmaxThermal "isothermal" 
     .XsymmetryThermal "none" 
     .YsymmetryThermal "none" 
     .ZsymmetryThermal "none" 
     .ApplyInAllDirections "False" 
     .XminTemperature "" 
     .XminTemperatureType "None" 
     .XmaxTemperature "" 
     .XmaxTemperatureType "None" 
     .YminTemperature "" 
     .YminTemperatureType "None" 
     .YmaxTemperature "" 
     .YmaxTemperatureType "None" 
     .ZminTemperature "" 
     .ZminTemperatureType "None" 
     .ZmaxTemperature "" 
     .ZmaxTemperatureType "None" 
     .XPeriodicShift "phase" 
     .YPeriodicShift "0.0" 
     .ZPeriodicShift "0.0" 
     .PeriodicUseConstantAngles "False" 
End With

'@ define frequency range

'[VERSION]2011.7|21.0.0|20111130[/VERSION]
Solver.FrequencyRange "0.0", "10.0"

'@ set pba mesh type

'[VERSION]2011.7|21.0.0|20111130[/VERSION]
Mesh.MeshType "PBA"

'@ pick face

'[VERSION]2011.7|21.0.0|20111130[/VERSION]
Pick.PickFaceFromId "component1:meander line", "19"

'@ align wcs with face

'[VERSION]2011.7|21.0.0|20111130[/VERSION]
WCS.AlignWCSWithSelected "Face"

'@ define eigenmode solver parameters

'[VERSION]2011.7|21.0.0|20111130[/VERSION]
Mesh.SetCreator "High Frequency" 
With Solver
     .CalculationType "Eigenmode" 
     .EigenmodeSolverType "JDM (low memory)" 
     .EigenmodeSolverMeshType "Hexahedral Mesh" 
     .AKSReset 
     .AKSModes "1" 
     .AKSPenaltyFactor "1" 
     .AKSEstimation "0" 
     .AKSAutomaticEstimation "True" 
     .AKSEstimationCycles "5" 
     .AKSIterations "2" 
     .AKSAccuracy "1e-012" 
     .StoreEigenmodeResultsInCache "False" 
     .AKSAdaptionActive "False" 
     .CalculateExternalQFactor "False" 
     .EigenmodeSolverUsePerturbation "False" 
     .ConsiderStaticModes "True" 
     .ModesInFrequencyRange "False" 
     .FrequencyTarget "True", "0.0" 
     .EigenmodeSolverAccuracy "1e-6" 
     .EigenmodeQExternalAccuracy "1e-4" 
     .EigenmodeSolverEpsFrequency "True", "" 
     .EigenmodeSolverTDCompatibleMaterials "False" 
End With

'@ set parametersweep options

'[VERSION]2011.7|21.0.0|20111130[/VERSION]
With ParameterSweep
    .SetSimulationType "Eigenmode" 
End With

'@ add watch: userdefined

'[VERSION]2011.7|21.0.0|20111130[/VERSION]
With ParameterSweep
     .AddUserdefinedWatch
End With

'@ add parsweep sequence: Sequence 1

'[VERSION]2011.7|21.0.0|20111130[/VERSION]
With ParameterSweep
     .AddSequence "Sequence 1" 
End With

'@ add parsweep parameter: Sequence 1:phase

'[VERSION]2011.7|21.0.0|20111130[/VERSION]
With ParameterSweep
     .AddParameter "Sequence 1", "phase", "True", "11.3", "33.92", "3" 
End With

'@ pick face

'[VERSION]2011.7|21.0.0|20111130[/VERSION]
Pick.PickFaceFromId "component1:meander line", "19"

'@ align wcs with face

'[VERSION]2011.7|21.0.0|20111130[/VERSION]
WCS.AlignWCSWithSelected "Face"

'@ edit parsweep parameter: Sequence 1:phase

'[VERSION]2011.7|21.0.0|20111130[/VERSION]
With ParameterSweep
     .DeleteParameter "Sequence 1", "phase" 
     .AddParameter "Sequence 1", "phase", "True", "45", "90", "2" 
End With


'@ define material: Taconic RF-35 (loss free)

'[VERSION]2011.7|21.0.0|20111130[/VERSION]
With Material
     .Reset
     .Name "Taconic RF-35 (loss free)"
.FrqType "all" 
.Type "Normal" 
.SetMaterialUnit "GHz", "mm"
.Epsilon "3.5" 
.Mue "1.0" 
.Kappa "0.0" 
.TanD "0.0" 
.TanDFreq "0.0" 
.TanDGiven "False" 
.TanDModel "ConstTanD" 
.KappaM "0.0" 
.TanDM "0.0" 
.TanDMFreq "0.0" 
.TanDMGiven "False" 
.TanDMModel "ConstKappa" 
.DispModelEps "None" 
.DispModelMue "None" 
.DispersiveFittingSchemeEps "General 1st" 
.DispersiveFittingSchemeMue "General 1st" 
.UseGeneralDispersionEps "False" 
.UseGeneralDispersionMue "False" 
.Rho "0.0" 
.ThermalType "Normal" 
.ThermalConductivity "0.24" 
.SetActiveMaterial "all" 
.Colour "0.75", "0.95", "0.85" 
.Wireframe "False" 
.Transparency "0" 
.Create
End With 


'@ change material: component1:substrate to: Taconic RF-35 (loss free)

'[VERSION]2011.7|21.0.0|20111130[/VERSION]
Solid.ChangeMaterial "component1:substrate", "Taconic RF-35 (loss free)" 


'@ edit parsweep parameter: Sequence 1:phase

'[VERSION]2011.7|21.0.0|20111130[/VERSION]
With ParameterSweep
     .DeleteParameter "Sequence 1", "phase" 
     .AddParameter "Sequence 1", "phase", "True", "17.72", "56.54", "6" 
End With


